@@ -17,16 +17,20 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Utils.py,v 1.4 1999/09/15 09:29:28 gobry Exp $
+# $Id: Utils.py,v 1.1.1.1 1999/11/22 13:29:31 fredgo Exp $
 
 from gtk import *
 from gnome.ui import *
 
 from Pyblio import Config
 
+import gettext
+_ = gettext.gettext
+
+
 tooltips = GtkTooltips ()
 
-if Config.get ("gnomeui/tooltips").data:
+if Config.get ('gnomeui/tooltips').data:
     tooltips.enable ()
 else:
     tooltips.disable ()
@@ -36,7 +40,7 @@ cursor ['clock']  = cursor_new (150)
 cursor ['normal'] = cursor_new (68)
 
 def set_cursor (self, name):
-    if not Config.get ("gnomeui/threads").data: return
+    if not Config.get ('gnomeui/threads').data: return
 
     self.get_window ().set_cursor (cursor [name])
         
@@ -51,11 +55,11 @@ def set_cursor (self, name):
     return
 
 def popup_add (menu, item, action = None, argument = None):
-    """ Helper to add a new menu entry """
+    ''' Helper to add a new menu entry '''
     
     tmp = GtkMenuItem (item)
     if action:
-        tmp.connect ("activate", action, argument)
+        tmp.connect ('activate', action, argument)
     
     tmp.show ()
     menu.append (tmp)
@@ -68,7 +72,7 @@ def error_dialog (title, err):
     dialog.set_usize (500, 300)
             
     text = GtkText ()
-    text.insert_defaults ("The following errors occured:\n\n")
+    text.insert_defaults (_("The following errors occured:\n\n"))
     text.insert (None, color ['red'], None, str (err))
     
     holder = GtkScrolledWindow ()
@@ -86,8 +90,8 @@ color = {}
 def init_colors (colormap):
     color [' colormap '] = colormap
     
-    color ['red']  = colormap.alloc ("red")
-    color ['blue'] = colormap.alloc ("blue")
+    color ['red']  = colormap.alloc ('red')
+    color ['blue'] = colormap.alloc ('blue')
     return
 
 
